searchNodes=[{"doc":"CPF module that provides functions to verify if a CPF is valid.","ref":"CPF.html","title":"CPF","type":"module"},{"doc":"Checks if the given argument is CPF.t() type. Examples iex&gt; CPF.cpf?(563_606_676_73) false iex&gt; &quot;56360667673&quot; |&gt; CPF.new() |&gt; CPF.cpf?() true","ref":"CPF.html#cpf?/1","title":"CPF.cpf?/1","type":"function"},{"doc":"Returns a tuple with the eleven digits of the given cpf.","ref":"CPF.html#digits/1","title":"CPF.digits/1","type":"function"},{"doc":"Cleans up all characters of a given input except numbers. It can make CPF validation more flexbile. Examples iex&gt; CPF.flex(&quot; 04.4 .8*58().476-08 &quot;) &quot;04485847608&quot; iex&gt; &quot; 04.4 .8*58().476-08 &quot; |&gt; CPF.flex() |&gt; CPF.valid?() true","ref":"CPF.html#flex/1","title":"CPF.flex/1","type":"function"},{"doc":"Returns a formatted string from a given cpf. Examples iex&gt; 563_606_676_73 |&gt; CPF.new() |&gt; CPF.format() &quot;563.606.676-73&quot;","ref":"CPF.html#format/1","title":"CPF.format/1","type":"function"},{"doc":"Generates a random valid CPF. Examples iex&gt; CPF.generate() |&gt; to_string() |&gt; CPF.valid? true","ref":"CPF.html#generate/0","title":"CPF.generate/0","type":"function"},{"doc":"Generates a predictable random valid CPF wit the given seed. Examples iex&gt; seed = {:exrop, [40_738_532_209_663_091 | 74_220_507_755_601_615]} iex&gt; seed |&gt; CPF.generate() |&gt; CPF.format() &quot;671.835.731-68&quot;","ref":"CPF.html#generate/1","title":"CPF.generate/1","type":"function"},{"doc":"Initializes a CPF. Examples iex&gt; CPF.new(563_606_676_73) #CPF&lt;563.606.676-73&gt; iex&gt; CPF.new(&quot;56360667673&quot;) #CPF&lt;563.606.676-73&gt; This function doesn&#39;t check if CPF numbers are valid, only use this function if the given String.t or the integer was validated before.","ref":"CPF.html#new/1","title":"CPF.new/1","type":"function"},{"doc":"Builds a CPF struct by validating its digits and format. Returns an ok/error tuple for valid/invalid CPFs. Examples iex&gt; {:ok, cpf} = CPF.parse(563_606_676_73) iex&gt; cpf #CPF&lt;563.606.676-73&gt; iex&gt; CPF.parse(563_606_676_72) {:error, %CPF.ParsingError{reason: :invalid_verifier}}","ref":"CPF.html#parse/1","title":"CPF.parse/1","type":"function"},{"doc":"Builds a CPF struct by validating its digits and format. Returns an CPF type or raises an CPF.ParsingError exception. Examples iex&gt; CPF.parse!(563_606_676_73) #CPF&lt;563.606.676-73&gt; iex&gt; CPF.parse!(563_606_676_72) ** (CPF.ParsingError) invalid_verifier","ref":"CPF.html#parse!/1","title":"CPF.parse!/1","type":"function"},{"doc":"Returns a integer representation of the given cpf. Examples iex&gt; 4_485_847_608 |&gt; CPF.new() |&gt; CPF.to_integer() 4_485_847_608","ref":"CPF.html#to_integer/1","title":"CPF.to_integer/1","type":"function"},{"doc":"Returns true the given cpf is valid, otherwise false. Examples iex&gt; CPF.valid?(563_606_676_73) true iex&gt; CPF.valid?(563_606_676_72) false iex&gt; CPF.valid?(&quot;563.606.676-73&quot;) true iex&gt; CPF.valid?(&quot;563/60.6-676/73&quot;) false iex&gt; CPF.valid?(&quot;563.606.676-72&quot;) false iex&gt; CPF.valid?(&quot;56360667673&quot;) true iex&gt; CPF.valid?(&quot;56360667672&quot;) false","ref":"CPF.html#valid?/1","title":"CPF.valid?/1","type":"function"},{"doc":"A text in String.t() or a positive integer","ref":"CPF.html#t:input/0","title":"CPF.input/0","type":"type"},{"doc":"The CPF type. It&#39; composed of eleven digits(0-9]).","ref":"CPF.html#t:t/0","title":"CPF.t/0","type":"opaque"},{"doc":"Provide functions to validate CPF field in a changeset.","ref":"CPF.Ecto.Changeset.html","title":"CPF.Ecto.Changeset","type":"module"},{"doc":"Verifies if given field in the changeset has a valid CPF. Examples iex&gt; {%{}, %{cpf: :string}} ...&gt; |&gt; Ecto.Changeset.cast(%{&quot;cpf&quot; =&gt; &quot;aaa&quot;}, [:cpf]) ...&gt; |&gt; CPF.Ecto.Changeset.validate_cpf(:cpf) ...&gt; |&gt; Map.get(:errors) [cpf: {&quot;is invalid&quot;, [reason: :invalid_format]}] iex&gt; {%{}, %{cpf: :string}} ...&gt; |&gt; Ecto.Changeset.cast(%{&quot;cpf&quot; =&gt; &quot;429.329.147-40&quot;}, [:cpf]) ...&gt; |&gt; CPF.Ecto.Changeset.validate_cpf(:cpf) ...&gt; |&gt; Map.get(:errors) [] iex&gt; {%{}, %{cpf: :string}} ...&gt; |&gt; Ecto.Changeset.cast(%{&quot;cpf&quot; =&gt; &quot;42932914740&quot;}, [:cpf]) ...&gt; |&gt; CPF.Ecto.Changeset.validate_cpf(:cpf) ...&gt; |&gt; Map.get(:errors) []","ref":"CPF.Ecto.Changeset.html#validate_cpf/2","title":"CPF.Ecto.Changeset.validate_cpf/2","type":"function"},{"doc":"","ref":"CPF.Ecto.Changeset.html#t:changeset/0","title":"CPF.Ecto.Changeset.changeset/0","type":"type"},{"doc":"Provide you functions to use the CPF type in your Ecto schema fields. Usage defmodule MyApp.MySchema do use Ecto.Schema # Import the cpf_type/1 helper import CPF.Ecto.Type schema &quot;my_schemas&quot; do # use the helpers functions in any field field :cpf, cpf_type(:string) end end","ref":"CPF.Ecto.Type.html","title":"CPF.Ecto.Type","type":"module"},{"doc":"A parameterized type macro function. cpf_type(:bigint) is a alias for CPF.Ecto.Type.Bigint cpf_type(:string) is a alias for CPF.Ecto.Type.String","ref":"CPF.Ecto.Type.html#cpf_type/1","title":"CPF.Ecto.Type.cpf_type/1","type":"macro"},{"doc":"Checks if the given CPFs are valid. Options --flex, only check the CPF digits and ignore any extra character Examples &gt; mix cpf.check 194.925.115-25 valid &gt; mix cpf.check 194.925.115-24 invalid &gt; mix cpf.check 194.925.115-25 19492511525 valid &gt; mix cpf.check 194.925.115.25 invalid &gt; mix cpf.check 194.925.115.25 --flex valid","ref":"Mix.Tasks.Cpf.Check.html","title":"Mix.Tasks.Cpf.Check","type":"task"},{"doc":"Generates a valid random CPF. Options --format, formats the CPF with the specified format: standard (default), formats the CPF using dots and slashes. digits, only display the CPF digits integer, returns the CPF as integer number --count, generates count times random CPFs Examples &gt; mix cpf.gen 194.925.115-25 &gt; mix cpf.gen --format=digits 19492511525 &gt; mix cpf.gen --format=integer 4485847608 &gt; mix cpf.gen --format=digits --count=2 19492511525 65313188640","ref":"Mix.Tasks.Cpf.Gen.html","title":"Mix.Tasks.Cpf.Gen","type":"task"},{"doc":"","ref":"CPF.ParsingError.html","title":"CPF.ParsingError","type":"exception"},{"doc":"Callback implementation for Exception.message/1.","ref":"CPF.ParsingError.html#message/1","title":"CPF.ParsingError.message/1","type":"function"},{"doc":"","ref":"CPF.ParsingError.html#t:t/0","title":"CPF.ParsingError.t/0","type":"type"},{"doc":"CPF A library to work with CPFs. CPF is an acronym for &quot;Cadastro de Pessoa Físicas,&quot; it&#39;s a unique number associated to a person that the Brazilian government maintains. With this number, it is possible to check or retrieve information about a person. This library provides a validation that checks if the number is a valid CPF number. The CPF has check digit algorithm is similar to ISBN 10, you can check the details in Portuguese here.","ref":"readme.html","title":"CPF","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding cpf to your list of dependencies in mix.exs: def deps do [ {:cpf, &quot;~&gt; 1.0&quot;} ] end","ref":"readme.html#installation","title":"CPF - Installation","type":"extras"},{"doc":"You can verify if a CPF is valid by calling the function CPF.valid?/1: iex&gt; CPF.valid?(563_606_676_73) true iex&gt; CPF.valid?(563_606_676_72) false iex&gt; CPF.valid?(&quot;563.606.676-73&quot;) true iex&gt; CPF.valid?(&quot;563.606.676-72&quot;) false iex&gt; CPF.valid?(&quot;56360667673&quot;) true iex&gt; CPF.valid?(&quot;56360667672&quot;) false","ref":"readme.html#quick-start","title":"CPF - Quick Start","type":"extras"},{"doc":"If you want to store CPF as integer or as String.t, this library have you covered. You can do: iex&gt; &quot;044.858.476-08&quot; |&gt; CPF.parse!() |&gt; CPF.to_integer() 4485847608 iex&gt; &quot;044.858.476-08&quot; |&gt; CPF.parse!() |&gt; to_string() &quot;04485847608&quot; Storing CPF as strings are easier for a human to read since the 0 padding digits are there. Meanwhile, storing as integers will allow you have better performance in CPF lookups. The CPF.parse/1 and CPF.parse!/1 returns you the CPF value wrapped in a custom type with explicit digits. iex&gt; CPF.parse(&quot;044.858.476-08&quot;) {:ok, #CPF&lt;&quot;044.858.476-08&quot;&gt;} iex&gt; CPF.parse(&quot;044.858.476-07&quot;) {:error, %CPF.ParsingError{reason: :invalid_verifier}} iex&gt; CPF.parse!(&quot;044.858.476-08&quot;) #CPF&lt;&quot;044.858.476-08&quot;&gt; iex&gt; CPF.parse!(&quot;044.858.476-07&quot;) ** (CPF.ParsingError) invalid verifier With the casted CPF in hands, you can use CPF.format/1, CPF.to_integer/1 and to_string/1.","ref":"readme.html#parsing-and-storing-cpfs","title":"CPF - Parsing and Storing CPFs","type":"extras"},{"doc":"If you have a valid CPF strings or integer in hands, you can use CPF.new/1 and in sequence call CPF.format/1: iex&gt; 4485847608 |&gt; CPF.new() |&gt; CPF.format() &quot;044.858.476-08&quot; iex&gt; &quot;04485847608&quot; |&gt; CPF.new() |&gt; CPF.format() &quot;044.858.476-08&quot; The CPF.format/1 expects the input be wrapped in the CPF type. Remember, only use CPF.new with valid CPFs, no other checks are done there. If you need some validation, use CPF.parse/1.","ref":"readme.html#cpf-formatting","title":"CPF - CPF Formatting","type":"extras"},{"doc":"You can generate valid CPF numbers by using CPF.generate/0: iex&gt; CPF.generate() #CPF&lt;671.835.731-68&gt; iex&gt; CPF.generate() |&gt; to_string() &quot;67183573168&quot; iex&gt; CPF.generate() |&gt; CPF.to_integer() 67183573168 iex&gt; CPF.generateI() |&gt; CPF.format() &quot;671.835.731-68&quot; After you generate the CPF, you can turn the CPF into a formatted string, or convert to a string digits, or convert to integer.","ref":"readme.html#generating-random-cpfs-for-testing","title":"CPF - Generating random CPFs for testing","type":"extras"},{"doc":"You can use CPF.flex/1 when you only care if the user has provided the correct number before any validation or parsing. For example: iex&gt; &quot;04.4.8*58().476-08&quot; |&gt; CPF.flex() |&gt; CPF.valid?() true iex&gt; &quot;04.4.8*58().476-08&quot; |&gt; CPF.flex() |&gt; CPF.parse!() |&gt; CPF.format() &quot;044.858.476-08&quot; It can be useful to take a user&#39;s dirty input and format it.","ref":"readme.html#flexibilizing-the-cpf-validation","title":"CPF - Flexibilizing the CPF validation","type":"extras"},{"doc":"You can generate random valid CPFs with: $ mix cpf.gen 194.925.115-25 $ mix cpf.gen --format=digits --count=2 19492511525 65313188640 You can also check if CPF are valid with: $ mix cpf.check 194.925.115-25 valid Run mix help cpf.gen and mix help cpf.check to read a further explanation about the commands available options.","ref":"readme.html#command-line","title":"CPF - Command line","type":"extras"},{"doc":"If you have ecto installed in your application, you can use the module CPF.Ecto.Type or CPF.Ecto.Changeset to cast and validate CPF fields. Using CPF.Ecto.Type If you like the strictness of types you can user CPF.Ecto.Type functions to define in your schema the CPF field type. For example: defmodule MyApp.Profile do use Ecto.Schema import Ecto.Changeset # Import the parameterized type function import CPF.Ecto.Type schema &quot;profiles&quot; do # use `cpf_type/1` in the field type definition field :cpf, cpf_type(:string) end def new(enum \\\\ %{}), do: struct!(__MODULE__, enum) def changeset(profile, params), do: cast(profile, params, __schema__(:fields)) end It will prevent any attempt to insert an invalid CPF when using your schema module. For example: {:error, changeset} = Profile.new() |&gt; Profile.changeset(%{cpf: &quot;abilidebob&quot;}) |&gt; MyApp.Repo.insert() {&quot;is invalid&quot;, [reason: :invalid_format]} = Keyword.get(changeset.errors, :cpf) Note: it will also prevent queries with invalid CPFs by raising casting error. You might need workaround it if you want to display an empty result with invalid CPFs. For example: if CPF.valid?(cpf) do query = from p in Profile, where: p.cpf == ^cpf Repo.all(query) else [] end If you&#39;re working in a search form, you might want to create a search_form_changeset and validate the search inputs before querying the database. Using CPF.Ecto.Changeset If you don&#39;t want use type in your CPF fields, you can use CPF.Ecto.Changeset.validate_cpf/2 function to validate a field in your changeset. Example: CPF.Ecto.Changeset.validate_cpf(changeset, :cpf) Using this approach you need manually cast the CPF field to store in uniform way. As example, you can do that using the Ecto.Change.prepare_changes/1. Example: changeset |&gt; CPF.Ecto.Changeset.validate_cpf(:cpf) |&gt; Ecto.Changeset.prepare_changes(fn changeset -&gt; if input = Ecto.Changeset.get_change(changeset, :cpf) do string_cpf = input |&gt; CPF.parse!() |&gt; to_string() Ecto.Changeset.put_change(changeset, :cpf, string_cpf) else changeset end end) The prepare_changes/2 will be called after the validation and before insert or update in the repository. It gives the developer the opportunity to transform the CPF value in any way they want.","ref":"readme.html#ecto-integration","title":"CPF - Ecto Integration","type":"extras"},{"doc":"This library runs 3 times faster and consume 3 times less memory and work with primitive types, no extra struct is necessary.","ref":"readme.html#why-not-other-libraries","title":"CPF - Why not other libraries?","type":"extras"},{"doc":"The docs can be found at https://hexdocs.pm/cpf.","ref":"readme.html#docs","title":"CPF - Docs","type":"extras"}]